<?php
/**
 * Adds Drivili_Widget widget.
 */

class Drivili_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'drivili_Widget', // Base ID
			esc_html__( 'Drivili carpooling', 'drivili_domain' ), // Name
			array( 'description' => esc_html__( 'Widget to display trips from Drivili carpooling app', 'drivili_domain' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
    echo $args['before_widget'];
    
		if ( ! empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		$height = 500;
		if ($instance['height']) {
			$height = $instance['height'];
		}
		$width = '100%';
		$minWidth = '300px';
		$city_name = '';
		$country_name = '';
		if ($instance['city_selection'] == 'manual') {
			$city_name = $instance['city_name'];
			$country_name = $instance['country_name'];
		}
    echo ' <iframe id="player_iframe" scrolling="no" src="https://drivili.com/#/?isPlugin=true&language='.$instance['language'].'&city_name='.$city_name.'&country_name='.$country_name.'" frameborder="0" width="'.$width.'" min-width="'.$minWidth.'" height="'.$height.'"></iframe>';

		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'Drivili carpooling', 'drivili_domain' );
		$height = ! empty( $instance['height'] ) ? $instance['height'] : esc_html__( '500', 'drivili_domain' );
		$language = ! empty( $instance['language'] ) ? $instance['language'] : esc_html__( 'auto', 'drivili_domain' );
		$city_selection = ! empty( $instance['city_selection'] ) ? $instance['city_selection'] : esc_html__( 'auto', 'drivili_domain' );
		$city_name = ! empty( $instance['city_name'] ) ? $instance['city_name'] : esc_html__( '', 'drivili_domain' );
		$country_name = ! empty( $instance['country_name'] ) ? $instance['country_name'] : esc_html__( '', 'drivili_domain' );
		$languages = array(
			'English' => 'en',
			'Français' => 'fr',
			'Español' => 'es',
			'Deutsche' => 'de',
			'Português' => 'pt',
			'Italiano' => 'it',
			'العربية' => 'ar'
		);
		?>

		<!-- TITLE SECTION -->
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>">
        <?php esc_attr_e( 'Title:', 'drivili_domain' ); ?>
      </label> 
      <input 
          class="widefat" 
          id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" 
          name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" 
          type="text" 
          value="<?php echo esc_attr( $title ); ?>">
		</p>
		<!-- HEIGHT SECTION -->
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'height' ) ); ?>">
        <?php esc_attr_e( 'Height:', 'drivili_domain' ); ?>
      </label> 
      <input 
          class="widefat" 
          id="<?php echo esc_attr( $this->get_field_id( 'height' ) ); ?>" 
          name="<?php echo esc_attr( $this->get_field_name( 'height' ) ); ?>" 
          type="number"
					min="450"
					max="1000" 
          value="<?php echo esc_attr( $height ); ?>">
		</p>
		<!-- LANGUAGE SECTION -->
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'language' ) ); ?>">
        <?php esc_attr_e( 'Language:', 'drivili_domain' ); ?>
      </label> 
      <select 
          class="widefat" 
          id="<?php echo esc_attr( $this->get_field_id( 'language' ) ); ?>" 
          name="<?php echo esc_attr( $this->get_field_name( 'language' ) ); ?>" >

					<option value="auto" <?php echo ($language == 'auto') ? 'selected' : ''; ?> > auto </option>

					<!-- all languages -->
					<?php
						foreach ($languages as $lang => $value) {
							?>
							<option value="<?php echo $value ?>" <?php echo ($language == $value) ? 'selected' : ''; ?> > <?php echo $lang ?> </option>
							<?php
						}
					?>


			</select>
		</p>

		<!-- CITY SELECTION SECTION -->
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'city_selection' ) ); ?>">
        <?php esc_attr_e( 'City selection:', 'drivili_domain' ); ?>
      </label> 
      <select 
          class="widefat" 
          id="<?php echo esc_attr( $this->get_field_id( 'city_selection' ) ); ?>" 
          name="<?php echo esc_attr( $this->get_field_name( 'city_selection' ) ); ?>" >

					<option value="auto" <?php echo ($city_selection == 'auto') ? 'selected' : ''; ?> > auto </option>
					<option value="manual" <?php echo ($city_selection == 'manual') ? 'selected' : ''; ?> > manual </option>

			</select>
		</p>

		<?php

		if ($instance['city_selection'] == 'manual') { ?>

		<!-- CITY NAME SECTION -->
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'city_name' ) ); ?>">
        <?php esc_attr_e( 'City name:', 'drivili_domain' ); ?>
      </label> 
      <input 
          class="widefat" 
          id="<?php echo esc_attr( $this->get_field_id( 'city_name' ) ); ?>" 
          name="<?php echo esc_attr( $this->get_field_name( 'city_name' ) ); ?>" 
          type="text" 
          value="<?php echo esc_attr( $city_name ); ?>">
		</p>

		<!-- COUNTRY NAME SECTION -->
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'country_name' ) ); ?>">
        <?php esc_attr_e( 'Country name:', 'drivili_domain' ); ?>
      </label> 
      <input 
          class="widefat" 
          id="<?php echo esc_attr( $this->get_field_id( 'country_name' ) ); ?>" 
          name="<?php echo esc_attr( $this->get_field_name( 'country_name' ) ); ?>" 
          type="text" 
          value="<?php echo esc_attr( $country_name ); ?>">
		</p>

		<?php 
		
		}

		?>

		<?php 
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['height'] = ( ! empty( $new_instance['height'] ) ) ? strip_tags( $new_instance['height'] ) : '';
		$instance['language'] = ( ! empty( $new_instance['language'] ) ) ? strip_tags( $new_instance['language'] ) : '';
		$instance['city_selection'] = ( ! empty( $new_instance['city_selection'] ) ) ? strip_tags( $new_instance['city_selection'] ) : '';
		$instance['city_name'] = ( ! empty( $new_instance['city_name'] ) ) ? strip_tags( $new_instance['city_name'] ) : '';
		$instance['country_name'] = ( ! empty( $new_instance['country_name'] ) ) ? strip_tags( $new_instance['country_name'] ) : '';

		return $instance;
	}

} // class Drivili_Widget